@@ -20,20 +20,25 @@ databricks_expand_jars <- function() {
 }
 
 databricks_connection <- function(config, extensions) {
-  tryCatch({
-    databricks_expand_jars()
+  tryCatch(
+    {
+      databricks_expand_jars()
 
-    callSparkR <- get("callJStatic", envir = asNamespace("SparkR"))
-    # In Databricks environments (notebooks & rstudio) DATABRICKS_GUID is in the default namespace
-    guid <- get("DATABRICKS_GUID", envir = .GlobalEnv)
-    gatewayPort <- as.numeric(callSparkR("com.databricks.backend.daemon.driver.RDriverLocal",
-                                         "startSparklyr",
-                                         guid,
-                                         # startSparklyr will search & find proper JAR file
-                                         system.file("java/", package = "sparklyr")))
-  }, error = function(err) {
-    stop("Failed to start sparklyr backend: ", err$message)
-  })
+      callSparkR <- get("callJStatic", envir = asNamespace("SparkR"))
+      # In Databricks environments (notebooks & rstudio) DATABRICKS_GUID is in the default namespace
+      guid <- get("DATABRICKS_GUID", envir = .GlobalEnv)
+      gatewayPort <- as.numeric(callSparkR(
+        "com.databricks.backend.daemon.driver.RDriverLocal",
+        "startSparklyr",
+        guid,
+        # startSparklyr will search & find proper JAR file
+        system.file("java/", package = "sparklyr")
+      ))
+    },
+    error = function(err) {
+      stop("Failed to start sparklyr backend: ", err$message)
+    }
+  )
 
   new_databricks_connection(
     gateway_connection(
@@ -46,8 +51,9 @@ databricks_connection <- function(config, extensions) {
 
 #' @export
 spark_version.databricks_connection <- function(sc) {
-  if (!is.null(sc$state$spark_version))
+  if (!is.null(sc$state$spark_version)) {
     return(sc$state$spark_version)
+  }
 
   version <- eval(rlang::parse_expr("SparkR::sparkR.version()"))
 
