@@ -1,7 +1,6 @@
 # nocov start
 
-worker_invoke_method <- function(sc, static, object, method, ...)
-{
+worker_invoke_method <- function(sc, static, object, method, ...) {
   core_invoke_method(sc, static, object, method, ...)
 }
 
